Class: Google::Cloud::Tasks::V2beta3::BatchCreateTasksMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb

Overview

Metadata message for [BatchCreateTasks].

Defined Under Namespace

Modules: State Classes: FailedRequestsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#end_time::Google::Protobuf::Timestamp

Returns The time when the batch create finished.

Returns:



526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
# File 'proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb', line 526

class BatchCreateTasksMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::Integer]
  # @!attribute [rw] value
  #   @return [::Google::Rpc::Status]
  class FailedRequestsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state of the batch create operation.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The batch create is running.
    RUNNING = 1

    # The batch create has finished.
    # All tasks in the request were successfully created.
    SUCCEEDED = 2

    # The batch create has finished with partial success.
    # The tasks that failed to be created are reported in
    # {::Google::Cloud::Tasks::V2beta3::BatchCreateTasksMetadata#failed_requests failed_requests}.
    PARTIALLY_SUCCEEDED = 5

    # The batch create has failed.
    # This means the overall batch create operation failed to complete.
    # This can happen due to an internal error preventing the operation from
    # finishing.
    FAILED = 3

    # The batch create was cancelled.
    CANCELLED = 4
  end
end

#failed_requests::Google::Protobuf::Map{::Integer => ::Google::Rpc::Status}

Returns A map of failed requests, where the key is the index of the request in BatchCreateTasksRequest.requests and the value is the error status.

Returns:

  • (::Google::Protobuf::Map{::Integer => ::Google::Rpc::Status})

    A map of failed requests, where the key is the index of the request in BatchCreateTasksRequest.requests and the value is the error status.



526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
# File 'proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb', line 526

class BatchCreateTasksMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::Integer]
  # @!attribute [rw] value
  #   @return [::Google::Rpc::Status]
  class FailedRequestsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state of the batch create operation.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The batch create is running.
    RUNNING = 1

    # The batch create has finished.
    # All tasks in the request were successfully created.
    SUCCEEDED = 2

    # The batch create has finished with partial success.
    # The tasks that failed to be created are reported in
    # {::Google::Cloud::Tasks::V2beta3::BatchCreateTasksMetadata#failed_requests failed_requests}.
    PARTIALLY_SUCCEEDED = 5

    # The batch create has failed.
    # This means the overall batch create operation failed to complete.
    # This can happen due to an internal error preventing the operation from
    # finishing.
    FAILED = 3

    # The batch create was cancelled.
    CANCELLED = 4
  end
end

#start_time::Google::Protobuf::Timestamp

Returns The time when the batch create started.

Returns:



526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
# File 'proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb', line 526

class BatchCreateTasksMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::Integer]
  # @!attribute [rw] value
  #   @return [::Google::Rpc::Status]
  class FailedRequestsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state of the batch create operation.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The batch create is running.
    RUNNING = 1

    # The batch create has finished.
    # All tasks in the request were successfully created.
    SUCCEEDED = 2

    # The batch create has finished with partial success.
    # The tasks that failed to be created are reported in
    # {::Google::Cloud::Tasks::V2beta3::BatchCreateTasksMetadata#failed_requests failed_requests}.
    PARTIALLY_SUCCEEDED = 5

    # The batch create has failed.
    # This means the overall batch create operation failed to complete.
    # This can happen due to an internal error preventing the operation from
    # finishing.
    FAILED = 3

    # The batch create was cancelled.
    CANCELLED = 4
  end
end

#state::Google::Cloud::Tasks::V2beta3::BatchCreateTasksMetadata::State (readonly)

Returns Output only. The state of the batch create operation.

Returns:



526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
# File 'proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb', line 526

class BatchCreateTasksMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::Integer]
  # @!attribute [rw] value
  #   @return [::Google::Rpc::Status]
  class FailedRequestsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state of the batch create operation.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The batch create is running.
    RUNNING = 1

    # The batch create has finished.
    # All tasks in the request were successfully created.
    SUCCEEDED = 2

    # The batch create has finished with partial success.
    # The tasks that failed to be created are reported in
    # {::Google::Cloud::Tasks::V2beta3::BatchCreateTasksMetadata#failed_requests failed_requests}.
    PARTIALLY_SUCCEEDED = 5

    # The batch create has failed.
    # This means the overall batch create operation failed to complete.
    # This can happen due to an internal error preventing the operation from
    # finishing.
    FAILED = 3

    # The batch create was cancelled.
    CANCELLED = 4
  end
end