Module: Google::Cloud::Tasks::V2beta3::BatchCreateTasksMetadata::State

Defined in:
proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb

Overview

The state of the batch create operation.

Constant Summary collapse

STATE_UNSPECIFIED =

The default value. This value is used if the state is omitted.

0
RUNNING =

The batch create is running.

1
SUCCEEDED =

The batch create has finished. All tasks in the request were successfully created.

2
PARTIALLY_SUCCEEDED =

The batch create has finished with partial success. The tasks that failed to be created are reported in failed_requests.

5
FAILED =

The batch create has failed. This means the overall batch create operation failed to complete. This can happen due to an internal error preventing the operation from finishing.

3
CANCELLED =

The batch create was cancelled.

4