Class: Google::Cloud::Tasks::V2beta3::BatchCreateTasksRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb

Overview

Request message for [BatchCreateTasks].

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The queue name. For example: projects/PROJECT_ID/locations/LOCATION_ID/queues/QUEUE_ID

The queue must already exist.

Returns:

  • (::String)

    Required. The queue name. For example: projects/PROJECT_ID/locations/LOCATION_ID/queues/QUEUE_ID

    The queue must already exist.



377
378
379
380
# File 'proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb', line 377

class BatchCreateTasksRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. This field will be used to identify the long running operation, avoiding duplication when user retries. If not provided, then a UUID will be generated at server side.

Returns:

  • (::String)

    Optional. This field will be used to identify the long running operation, avoiding duplication when user retries. If not provided, then a UUID will be generated at server side.



377
378
379
380
# File 'proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb', line 377

class BatchCreateTasksRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#requests::Array<::Google::Cloud::Tasks::V2beta3::CreateTaskRequest>

Returns Required. The list of requests to create tasks. The queue specified in parent field of each CreateTaskRequest will be the same. This validation happens on the client side as well as in the handler. BatchCreateTasksRequest.parent will also be the same value as the individual CreateTaskRequest.parent . The maximum number of requests is 100.

Returns:

  • (::Array<::Google::Cloud::Tasks::V2beta3::CreateTaskRequest>)

    Required. The list of requests to create tasks. The queue specified in parent field of each CreateTaskRequest will be the same. This validation happens on the client side as well as in the handler. BatchCreateTasksRequest.parent will also be the same value as the individual CreateTaskRequest.parent . The maximum number of requests is 100.



377
378
379
380
# File 'proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb', line 377

class BatchCreateTasksRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end