Class: Google::Cloud::Tasks::V2beta3::BatchDeleteTasksMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb

Overview

Metadata for the long-running operation returned by BatchDeleteTasks. This message is used to hold metadata information about the batch delete tasks operation; that is, it is put in google.longrunning.Operation.metadata.

Defined Under Namespace

Modules: State Classes: FailedRequestsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#end_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the batch delete finished.

Returns:



434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
# File 'proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb', line 434

class BatchDeleteTasksMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::Integer]
  # @!attribute [rw] value
  #   @return [::Google::Rpc::Status]
  class FailedRequestsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state of the batch delete operation.
  # This enum is not frozen and new values may be added in the future.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The batch delete is running.
    RUNNING = 1

    # The batch delete has finished and all tasks were successfully deleted.
    SUCCEEDED = 2

    # The batch delete has finished with partial success.
    # The tasks that failed to be deleted are reported in
    # {::Google::Cloud::Tasks::V2beta3::BatchDeleteTasksMetadata#failed_requests failed_requests}.
    # When all requests in the batch fail,
    # {::Google::Longrunning::Operation#error google.longrunning.Operation.error}
    # will be set with `code` = `google.rpc.Code.ABORTED` and `message` = "None
    # of the requests succeeded, refer to
    # BatchDeleteTasksMetadata.failed_requests for individual error details".
    PARTIALLY_SUCCEEDED = 3

    # The batch delete has failed.
    # This means the overall batch delete operation failed to complete.
    # This can happen due to an internal error preventing the operation from
    # finishing.
    FAILED = 4
  end
end

#failed_requests::Google::Protobuf::Map{::Integer => ::Google::Rpc::Status} (readonly)

Returns Output only. A map of failed requests, where the key is the index of the request in BatchDeleteTasksRequest.names and the value is the error status.

Returns:

  • (::Google::Protobuf::Map{::Integer => ::Google::Rpc::Status})

    Output only. A map of failed requests, where the key is the index of the request in BatchDeleteTasksRequest.names and the value is the error status.



434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
# File 'proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb', line 434

class BatchDeleteTasksMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::Integer]
  # @!attribute [rw] value
  #   @return [::Google::Rpc::Status]
  class FailedRequestsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state of the batch delete operation.
  # This enum is not frozen and new values may be added in the future.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The batch delete is running.
    RUNNING = 1

    # The batch delete has finished and all tasks were successfully deleted.
    SUCCEEDED = 2

    # The batch delete has finished with partial success.
    # The tasks that failed to be deleted are reported in
    # {::Google::Cloud::Tasks::V2beta3::BatchDeleteTasksMetadata#failed_requests failed_requests}.
    # When all requests in the batch fail,
    # {::Google::Longrunning::Operation#error google.longrunning.Operation.error}
    # will be set with `code` = `google.rpc.Code.ABORTED` and `message` = "None
    # of the requests succeeded, refer to
    # BatchDeleteTasksMetadata.failed_requests for individual error details".
    PARTIALLY_SUCCEEDED = 3

    # The batch delete has failed.
    # This means the overall batch delete operation failed to complete.
    # This can happen due to an internal error preventing the operation from
    # finishing.
    FAILED = 4
  end
end

#start_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the batch delete started.

Returns:



434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
# File 'proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb', line 434

class BatchDeleteTasksMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::Integer]
  # @!attribute [rw] value
  #   @return [::Google::Rpc::Status]
  class FailedRequestsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state of the batch delete operation.
  # This enum is not frozen and new values may be added in the future.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The batch delete is running.
    RUNNING = 1

    # The batch delete has finished and all tasks were successfully deleted.
    SUCCEEDED = 2

    # The batch delete has finished with partial success.
    # The tasks that failed to be deleted are reported in
    # {::Google::Cloud::Tasks::V2beta3::BatchDeleteTasksMetadata#failed_requests failed_requests}.
    # When all requests in the batch fail,
    # {::Google::Longrunning::Operation#error google.longrunning.Operation.error}
    # will be set with `code` = `google.rpc.Code.ABORTED` and `message` = "None
    # of the requests succeeded, refer to
    # BatchDeleteTasksMetadata.failed_requests for individual error details".
    PARTIALLY_SUCCEEDED = 3

    # The batch delete has failed.
    # This means the overall batch delete operation failed to complete.
    # This can happen due to an internal error preventing the operation from
    # finishing.
    FAILED = 4
  end
end

#state::Google::Cloud::Tasks::V2beta3::BatchDeleteTasksMetadata::State (readonly)

Returns Output only. The state of the batch delete operation.

Returns:



434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
# File 'proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb', line 434

class BatchDeleteTasksMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::Integer]
  # @!attribute [rw] value
  #   @return [::Google::Rpc::Status]
  class FailedRequestsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state of the batch delete operation.
  # This enum is not frozen and new values may be added in the future.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The batch delete is running.
    RUNNING = 1

    # The batch delete has finished and all tasks were successfully deleted.
    SUCCEEDED = 2

    # The batch delete has finished with partial success.
    # The tasks that failed to be deleted are reported in
    # {::Google::Cloud::Tasks::V2beta3::BatchDeleteTasksMetadata#failed_requests failed_requests}.
    # When all requests in the batch fail,
    # {::Google::Longrunning::Operation#error google.longrunning.Operation.error}
    # will be set with `code` = `google.rpc.Code.ABORTED` and `message` = "None
    # of the requests succeeded, refer to
    # BatchDeleteTasksMetadata.failed_requests for individual error details".
    PARTIALLY_SUCCEEDED = 3

    # The batch delete has failed.
    # This means the overall batch delete operation failed to complete.
    # This can happen due to an internal error preventing the operation from
    # finishing.
    FAILED = 4
  end
end