Class: Google::Cloud::Tasks::V2beta3::HttpTarget::HeaderOverride

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/tasks/v2beta3/target.rb

Overview

Wraps the Header object.

Instance Attribute Summary collapse

Instance Attribute Details

#header::Google::Cloud::Tasks::V2beta3::HttpTarget::Header

Returns Header embodying a key and a value.

Do not put business sensitive or personally identifying data in the HTTP Header Override Configuration or other similar fields in accordance with Section 12 (Resource Fields) of the Service Specific Terms.

Returns:



262
263
264
265
# File 'proto_docs/google/cloud/tasks/v2beta3/target.rb', line 262

class HeaderOverride
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end