Class: Google::Cloud::Tasks::V2beta3::PullMessage

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/tasks/v2beta3/target.rb

Overview

Pull Message.

This proto can only be used for tasks in a queue which has PULL type. It currently exists for backwards compatibility with the App Engine Task Queue SDK. This message type maybe returned with methods list and get, when the response view is FULL.

Instance Attribute Summary collapse

Instance Attribute Details

#payload::String

Returns A data payload consumed by the worker to execute the task.

Returns:

  • (::String)

    A data payload consumed by the worker to execute the task.



47
48
49
50
# File 'proto_docs/google/cloud/tasks/v2beta3/target.rb', line 47

class PullMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tag::String

Returns The tasks's tag.

The tag is less than 500 characters.

SDK compatibility: Although the SDK allows tags to be either string or bytes, only UTF-8 encoded tags can be used in Cloud Tasks. If a tag isn't UTF-8 encoded, the tag will be empty when the task is returned by Cloud Tasks.

Returns:

  • (::String)

    The tasks's tag.

    The tag is less than 500 characters.

    SDK compatibility: Although the SDK allows tags to be either string or bytes, only UTF-8 encoded tags can be used in Cloud Tasks. If a tag isn't UTF-8 encoded, the tag will be empty when the task is returned by Cloud Tasks.



47
48
49
50
# File 'proto_docs/google/cloud/tasks/v2beta3/target.rb', line 47

class PullMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end