Class: Google::Cloud::Tasks::V2beta3::UpdateCmekConfigRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Tasks::V2beta3::UpdateCmekConfigRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb
Overview
Request message for UpdateCmekConfig.
Instance Attribute Summary collapse
-
#cmek_config ⇒ ::Google::Cloud::Tasks::V2beta3::CmekConfig
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
List of fields to be updated in this request.
Instance Attribute Details
#cmek_config ⇒ ::Google::Cloud::Tasks::V2beta3::CmekConfig
Returns Required. The config to update. Its name attribute distinguishes it.
575 576 577 578 |
# File 'proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb', line 575 class UpdateCmekConfigRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns List of fields to be updated in this request.
575 576 577 578 |
# File 'proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb', line 575 class UpdateCmekConfigRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |