Module: Google::Cloud::Tasks::V2beta3::BatchDeleteTasksMetadata::State
- Defined in:
- proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb
Overview
The state of the batch delete operation. This enum is not frozen and new values may be added in the future.
Constant Summary collapse
- STATE_UNSPECIFIED =
The default value. This value is used if the state is omitted.
0- RUNNING =
The batch delete is running.
1- SUCCEEDED =
The batch delete has finished and all tasks were successfully deleted.
2- PARTIALLY_SUCCEEDED =
The batch delete has finished with partial success. The tasks that failed to be deleted are reported in failed_requests. When all requests in the batch fail, google.longrunning.Operation.error will be set with
code=google.rpc.Code.ABORTEDandmessage= "None of the requests succeeded, refer to BatchDeleteTasksMetadata.failed_requests for individual error details". 3- FAILED =
The batch delete has failed. This means the overall batch delete operation failed to complete. This can happen due to an internal error preventing the operation from finishing.
4