Class: Google::Cloud::Tasks::V2beta3::BatchDeleteTasksRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Tasks::V2beta3::BatchDeleteTasksRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb
Overview
Request message for deleting a batch of tasks using BatchDeleteTasks.
Instance Attribute Summary collapse
-
#names ⇒ ::Array<::String>
Required.
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#names ⇒ ::Array<::String>
Returns Required. The names of the tasks to delete.
A maximum of 1000 tasks can be deleted in a batch.
For example:
Format:
projects/PROJECT_ID/locations/LOCATION_ID/queues/QUEUE_ID/tasks/TASK_ID.
411 412 413 414 |
# File 'proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb', line 411 class BatchDeleteTasksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The queue name. For example:
Format: projects/PROJECT_ID/locations/LOCATION_ID/queues/QUEUE_ID.
411 412 413 414 |
# File 'proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb', line 411 class BatchDeleteTasksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. This field will be used to identify the long running operation, avoiding duplication when user retries. If not provided, then a UUID will be generated at server side.
411 412 413 414 |
# File 'proto_docs/google/cloud/tasks/v2beta3/cloudtasks.rb', line 411 class BatchDeleteTasksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |