Class: Google::Cloud::Tasks::V2beta3::CmekConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Tasks::V2beta3::CmekConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/tasks/v2beta3/cmek_config.rb
Overview
Describes the customer-managed encryption key (CMEK) configuration associated with a project and location.
Instance Attribute Summary collapse
-
#kms_key ⇒ ::String
Resource name of the Cloud KMS key, of the form
projects/PROJECT_ID/locations/LOCATION_ID/keyRings/KEY_RING_ID/cryptoKeys/KEY_ID, that will be used to encrypt the Queues & Tasks in the region. -
#name ⇒ ::String
readonly
Output only.
Instance Attribute Details
#kms_key ⇒ ::String
Returns Resource name of the Cloud KMS key, of the form
projects/PROJECT_ID/locations/LOCATION_ID/keyRings/KEY_RING_ID/cryptoKeys/KEY_ID,
that will be used to encrypt the Queues & Tasks in the region. Setting
this as blank will turn off CMEK encryption.
37 38 39 40 |
# File 'proto_docs/google/cloud/tasks/v2beta3/cmek_config.rb', line 37 class CmekConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String (readonly)
Returns Output only. The config resource name which includes the project and location and must end in 'cmekConfig', in the format projects/PROJECT_ID/locations/LOCATION_ID/cmekConfig`.
37 38 39 40 |
# File 'proto_docs/google/cloud/tasks/v2beta3/cmek_config.rb', line 37 class CmekConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |