Class: Google::Cloud::Tasks::V2beta3::HttpTarget
- Inherits:
-
Object
- Object
- Google::Cloud::Tasks::V2beta3::HttpTarget
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/tasks/v2beta3/target.rb
Overview
HTTP target.
When specified as a Queue, all the tasks with [HttpRequest] will be overridden according to the target.
Defined Under Namespace
Classes: Header, HeaderOverride
Instance Attribute Summary collapse
-
#header_overrides ⇒ ::Array<::Google::Cloud::Tasks::V2beta3::HttpTarget::HeaderOverride>
HTTP target headers.
-
#http_method ⇒ ::Google::Cloud::Tasks::V2beta3::HttpMethod
The HTTP method to use for the request.
-
#oauth_token ⇒ ::Google::Cloud::Tasks::V2beta3::OAuthToken
If specified, an OAuth token is generated and attached as the
Authorizationheader in the HTTP request. -
#oidc_token ⇒ ::Google::Cloud::Tasks::V2beta3::OidcToken
If specified, an OIDC token is generated and attached as an
Authorizationheader in the HTTP request. -
#uri_override ⇒ ::Google::Cloud::Tasks::V2beta3::UriOverride
URI override.
Instance Attribute Details
#header_overrides ⇒ ::Array<::Google::Cloud::Tasks::V2beta3::HttpTarget::HeaderOverride>
Returns HTTP target headers.
This map contains the header field names and values. Headers will be set when running the CreateTask and/or [BufferTask][google.cloud.tasks.v2beta3.CloudTasks.BufferTask].
These headers represent a subset of the headers that will be configured for the task's HTTP request. Some HTTP request headers will be ignored or replaced.
A partial list of headers that will be ignored or replaced is:
- Several predefined headers, prefixed with "X-CloudTasks-", can be used to define properties of the task.
- Host: This will be computed by Cloud Tasks and derived from [HttpRequest.url][google.cloud.tasks.v2beta3.Target.HttpRequest.url].
- Content-Length: This will be computed by Cloud Tasks.
Content-Type won't be set by Cloud Tasks. You can explicitly set
Content-Type to a media type when the
task is created.
For example,Content-Type can be set to "application/octet-stream" or
"application/json". The default value is set to "application/json".
- User-Agent: This will be set to
"Google-Cloud-Tasks".
Headers which can have multiple values (according to RFC2616) can be specified using comma-separated values.
The size of the headers must be less than 80KB. Queue-level headers to override headers of all the tasks in the queue.
Do not put business sensitive or personally identifying data in the HTTP Header Override Configuration or other similar fields in accordance with Section 12 (Resource Fields) of the Service Specific Terms.
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'proto_docs/google/cloud/tasks/v2beta3/target.rb', line 237 class HttpTarget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines a header message. A header can have a key and a value. # @!attribute [rw] key # @return [::String] # The Key of the header. # @!attribute [rw] value # @return [::String] # The Value of the header. class Header include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Wraps the Header object. # @!attribute [rw] header # @return [::Google::Cloud::Tasks::V2beta3::HttpTarget::Header] # Header embodying a key and a value. # # Do not put business sensitive or personally identifying data in the HTTP # Header Override Configuration or other similar fields in accordance with # Section 12 (Resource Fields) of the # [Service Specific Terms](https://cloud.google.com/terms/service-terms). class HeaderOverride include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#http_method ⇒ ::Google::Cloud::Tasks::V2beta3::HttpMethod
Returns The HTTP method to use for the request.
When specified, it overrides HttpRequest.http_method for the task. Note that if the value is set to HttpMethod.GET the HttpRequest.body of the task will be ignored at execution time.
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'proto_docs/google/cloud/tasks/v2beta3/target.rb', line 237 class HttpTarget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines a header message. A header can have a key and a value. # @!attribute [rw] key # @return [::String] # The Key of the header. # @!attribute [rw] value # @return [::String] # The Value of the header. class Header include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Wraps the Header object. # @!attribute [rw] header # @return [::Google::Cloud::Tasks::V2beta3::HttpTarget::Header] # Header embodying a key and a value. # # Do not put business sensitive or personally identifying data in the HTTP # Header Override Configuration or other similar fields in accordance with # Section 12 (Resource Fields) of the # [Service Specific Terms](https://cloud.google.com/terms/service-terms). class HeaderOverride include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#oauth_token ⇒ ::Google::Cloud::Tasks::V2beta3::OAuthToken
Returns If specified, an
OAuth token
is generated and attached as the Authorization header in the HTTP
request.
This type of authorization should generally be used only when calling Google APIs hosted on *.googleapis.com. Note that both the service account email and the scope MUST be specified when using the queue-level authorization override.
Note: The following fields are mutually exclusive: oauth_token, oidc_token. If a field in that set is populated, all other fields in the set will automatically be cleared.
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'proto_docs/google/cloud/tasks/v2beta3/target.rb', line 237 class HttpTarget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines a header message. A header can have a key and a value. # @!attribute [rw] key # @return [::String] # The Key of the header. # @!attribute [rw] value # @return [::String] # The Value of the header. class Header include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Wraps the Header object. # @!attribute [rw] header # @return [::Google::Cloud::Tasks::V2beta3::HttpTarget::Header] # Header embodying a key and a value. # # Do not put business sensitive or personally identifying data in the HTTP # Header Override Configuration or other similar fields in accordance with # Section 12 (Resource Fields) of the # [Service Specific Terms](https://cloud.google.com/terms/service-terms). class HeaderOverride include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#oidc_token ⇒ ::Google::Cloud::Tasks::V2beta3::OidcToken
Returns If specified, an
OIDC
token is generated and attached as an Authorization header in the
HTTP request.
This type of authorization can be used for many scenarios, including calling Cloud Run, or endpoints where you intend to validate the token yourself. Note that both the service account email and the audience MUST be specified when using the queue-level authorization override.
Note: The following fields are mutually exclusive: oidc_token, oauth_token. If a field in that set is populated, all other fields in the set will automatically be cleared.
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'proto_docs/google/cloud/tasks/v2beta3/target.rb', line 237 class HttpTarget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines a header message. A header can have a key and a value. # @!attribute [rw] key # @return [::String] # The Key of the header. # @!attribute [rw] value # @return [::String] # The Value of the header. class Header include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Wraps the Header object. # @!attribute [rw] header # @return [::Google::Cloud::Tasks::V2beta3::HttpTarget::Header] # Header embodying a key and a value. # # Do not put business sensitive or personally identifying data in the HTTP # Header Override Configuration or other similar fields in accordance with # Section 12 (Resource Fields) of the # [Service Specific Terms](https://cloud.google.com/terms/service-terms). class HeaderOverride include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#uri_override ⇒ ::Google::Cloud::Tasks::V2beta3::UriOverride
Returns URI override.
When specified, overrides the execution URI for all the tasks in the queue.
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'proto_docs/google/cloud/tasks/v2beta3/target.rb', line 237 class HttpTarget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines a header message. A header can have a key and a value. # @!attribute [rw] key # @return [::String] # The Key of the header. # @!attribute [rw] value # @return [::String] # The Value of the header. class Header include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Wraps the Header object. # @!attribute [rw] header # @return [::Google::Cloud::Tasks::V2beta3::HttpTarget::Header] # Header embodying a key and a value. # # Do not put business sensitive or personally identifying data in the HTTP # Header Override Configuration or other similar fields in accordance with # Section 12 (Resource Fields) of the # [Service Specific Terms](https://cloud.google.com/terms/service-terms). class HeaderOverride include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |