Class: Google::Cloud::Tasks::V2beta3::PullMessage
- Inherits:
-
Object
- Object
- Google::Cloud::Tasks::V2beta3::PullMessage
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/tasks/v2beta3/target.rb
Overview
Instance Attribute Summary collapse
-
#payload ⇒ ::String
A data payload consumed by the worker to execute the task.
-
#tag ⇒ ::String
The tasks's tag.
Instance Attribute Details
#payload ⇒ ::String
Returns A data payload consumed by the worker to execute the task.
47 48 49 50 |
# File 'proto_docs/google/cloud/tasks/v2beta3/target.rb', line 47 class PullMessage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tag ⇒ ::String
Returns The tasks's tag.
The tag is less than 500 characters.
SDK compatibility: Although the SDK allows tags to be either string or bytes, only UTF-8 encoded tags can be used in Cloud Tasks. If a tag isn't UTF-8 encoded, the tag will be empty when the task is returned by Cloud Tasks.
47 48 49 50 |
# File 'proto_docs/google/cloud/tasks/v2beta3/target.rb', line 47 class PullMessage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |